import React from 'react';
import { AutoformatRule } from '@udecode/plate-autoformat';
import { ELEMENT_BLOCKQUOTE } from '@udecode/plate-block-quote';
import { ELEMENT_CODE_BLOCK, ELEMENT_CODE_LINE } from '@udecode/plate-code-block';
import { TCommentText } from '@udecode/plate-comments';
import { CreatePlateEditorOptions, Decorate, DecorateEntry, DOMHandler, EDescendant, EElement, EElementEntry, EElementOrText, EMarks, ENode, ENodeEntry, EText, ETextEntry, InjectComponent, InjectProps, KeyboardHandler, NoInfer, OnChange, OverrideByKey, PlateEditor, PlateId, PlatePlugin, PlatePluginComponent, PlatePluginInsertData, PlatePluginProps, PlateProps, PluginOptions, SerializeHtml, TElement, TNodeEntry, TReactEditor, TText, WithOverride } from '@udecode/plate-common';
import { ELEMENT_H1, ELEMENT_H2, ELEMENT_H3, ELEMENT_H4, ELEMENT_H5, ELEMENT_H6 } from '@udecode/plate-heading';
import { ELEMENT_HR } from '@udecode/plate-horizontal-rule';
import { ELEMENT_LINK, TLinkElement } from '@udecode/plate-link';
import { ELEMENT_LI, ELEMENT_OL, ELEMENT_TODO_LI, ELEMENT_UL, TTodoListItemElement } from '@udecode/plate-list';
import { ELEMENT_IMAGE, ELEMENT_MEDIA_EMBED, TImageElement, TMediaEmbedElement } from '@udecode/plate-media';
import { ELEMENT_MENTION, ELEMENT_MENTION_INPUT, TMentionElement, TMentionInputElement } from '@udecode/plate-mention';
import { ELEMENT_PARAGRAPH } from '@udecode/plate-paragraph';
import { ELEMENT_TABLE, ELEMENT_TD, ELEMENT_TR, TTableElement } from '@udecode/plate-table';
/**
 * Text
 */
export type EmptyText = {
    text: '';
};
export type PlainText = {
    text: string;
};
export interface RichText extends TText, TCommentText {
    bold?: boolean;
    italic?: boolean;
    underline?: boolean;
    strikethrough?: boolean;
    code?: boolean;
    kbd?: boolean;
    subscript?: boolean;
    backgroundColor?: React.CSSProperties['backgroundColor'];
    fontFamily?: React.CSSProperties['fontFamily'];
    color?: React.CSSProperties['color'];
    fontSize?: React.CSSProperties['fontSize'];
    fontWeight?: React.CSSProperties['fontWeight'];
}
/**
 * Inline Elements
 */
export interface MyLinkElement extends TLinkElement {
    type: typeof ELEMENT_LINK;
    children: RichText[];
}
export interface MyMentionInputElement extends TMentionInputElement {
    type: typeof ELEMENT_MENTION_INPUT;
    children: [PlainText];
}
export interface MyMentionElement extends TMentionElement {
    type: typeof ELEMENT_MENTION;
    children: [EmptyText];
}
export type MyInlineElement = MyLinkElement | MyMentionElement | MyMentionInputElement;
export type MyInlineDescendant = MyInlineElement | RichText;
export type MyInlineChildren = MyInlineDescendant[];
/**
 * Block props
 */
export interface MyIndentProps {
    indent?: number;
}
export interface MyIndentListProps extends MyIndentProps {
    listStart?: number;
    listRestart?: number;
    listStyleType?: string;
}
export interface MyLineHeightProps {
    lineHeight?: React.CSSProperties['lineHeight'];
}
export interface MyAlignProps {
    align?: React.CSSProperties['textAlign'];
}
export interface MyBlockElement extends TElement, MyIndentListProps, MyLineHeightProps {
    id?: PlateId;
}
/**
 * Blocks
 */
export interface MyParagraphElement extends MyBlockElement {
    type: typeof ELEMENT_PARAGRAPH;
    children: MyInlineChildren;
}
export interface MyH1Element extends MyBlockElement {
    type: typeof ELEMENT_H1;
    children: MyInlineChildren;
}
export interface MyH2Element extends MyBlockElement {
    type: typeof ELEMENT_H2;
    children: MyInlineChildren;
}
export interface MyH3Element extends MyBlockElement {
    type: typeof ELEMENT_H3;
    children: MyInlineChildren;
}
export interface MyH4Element extends MyBlockElement {
    type: typeof ELEMENT_H4;
    children: MyInlineChildren;
}
export interface MyH5Element extends MyBlockElement {
    type: typeof ELEMENT_H5;
    children: MyInlineChildren;
}
export interface MyH6Element extends MyBlockElement {
    type: typeof ELEMENT_H6;
    children: MyInlineChildren;
}
export interface MyBlockquoteElement extends MyBlockElement {
    type: typeof ELEMENT_BLOCKQUOTE;
    children: MyInlineChildren;
}
export interface MyCodeBlockElement extends MyBlockElement {
    type: typeof ELEMENT_CODE_BLOCK;
    children: MyCodeLineElement[];
}
export interface MyCodeLineElement extends TElement {
    type: typeof ELEMENT_CODE_LINE;
    children: PlainText[];
}
export interface MyTableElement extends TTableElement, MyBlockElement {
    type: typeof ELEMENT_TABLE;
    children: MyTableRowElement[];
}
export interface MyTableRowElement extends TElement {
    type: typeof ELEMENT_TR;
    children: MyTableCellElement[];
}
export interface MyTableCellElement extends TElement {
    type: typeof ELEMENT_TD;
    children: MyNestableBlock[];
}
export interface MyBulletedListElement extends TElement, MyBlockElement {
    type: typeof ELEMENT_UL;
    children: MyListItemElement[];
}
export interface MyNumberedListElement extends TElement, MyBlockElement {
    type: typeof ELEMENT_OL;
    children: MyListItemElement[];
}
export interface MyListItemElement extends TElement, MyBlockElement {
    type: typeof ELEMENT_LI;
    children: MyInlineChildren;
}
export interface MyTodoListElement extends TTodoListItemElement, MyBlockElement {
    type: typeof ELEMENT_TODO_LI;
    children: MyInlineChildren;
}
export interface MyImageElement extends TImageElement, MyBlockElement {
    type: typeof ELEMENT_IMAGE;
    children: [EmptyText];
}
export interface MyMediaEmbedElement extends TMediaEmbedElement, MyBlockElement {
    type: typeof ELEMENT_MEDIA_EMBED;
    children: [EmptyText];
}
export interface MyHrElement extends MyBlockElement {
    type: typeof ELEMENT_HR;
    children: [EmptyText];
}
export type MyNestableBlock = MyParagraphElement;
export type MyBlock = Exclude<MyElement, MyInlineElement>;
export type MyBlockEntry = TNodeEntry<MyBlock>;
export type MyRootBlock = MyParagraphElement | MyH1Element | MyH2Element | MyH3Element | MyH4Element | MyH5Element | MyH6Element | MyBlockquoteElement | MyCodeBlockElement | MyTableElement | MyBulletedListElement | MyNumberedListElement | MyTodoListElement | MyImageElement | MyMediaEmbedElement | MyHrElement;
export type MyValue = MyRootBlock[];
/**
 * Editor types
 */
export type MyEditor = PlateEditor<MyValue> & {
    isDragging?: boolean;
};
export type MyReactEditor = TReactEditor<MyValue>;
export type MyNode = ENode<MyValue>;
export type MyNodeEntry = ENodeEntry<MyValue>;
export type MyElement = EElement<MyValue>;
export type MyElementEntry = EElementEntry<MyValue>;
export type MyText = EText<MyValue>;
export type MyTextEntry = ETextEntry<MyValue>;
export type MyElementOrText = EElementOrText<MyValue>;
export type MyDescendant = EDescendant<MyValue>;
export type MyMarks = EMarks<MyValue>;
export type MyMark = keyof MyMarks;
/**
 * Plate types
 */
export type MyDecorate<P = PluginOptions> = Decorate<P, MyValue, MyEditor>;
export type MyDecorateEntry = DecorateEntry<MyValue>;
export type MyDOMHandler<P = PluginOptions> = DOMHandler<P, MyValue, MyEditor>;
export type MyInjectComponent = InjectComponent<MyValue>;
export type MyInjectProps = InjectProps<MyValue>;
export type MyKeyboardHandler<P = PluginOptions> = KeyboardHandler<P, MyValue, MyEditor>;
export type MyOnChange<P = PluginOptions> = OnChange<P, MyValue, MyEditor>;
export type MyOverrideByKey = OverrideByKey<MyValue, MyEditor>;
export type MyPlatePlugin<P = PluginOptions> = PlatePlugin<P, MyValue, MyEditor>;
export type MyPlatePluginInsertData = PlatePluginInsertData<MyValue>;
export type MyPlatePluginProps = PlatePluginProps<MyValue>;
export type MyPlateProps = PlateProps<MyValue, MyEditor>;
export type MySerializeHtml = SerializeHtml<MyValue>;
export type MyWithOverride<P = PluginOptions> = WithOverride<P, MyValue, MyEditor>;
/**
 * Plate store, Slate context
 */
export declare const getMyEditor: (editor: MyEditor) => import("@udecode/plate-common").Modify<MyEditor, {
    operations: import("@udecode/plate-common").TOperation<EElementOrText<MyValue>>[];
    isInline: (element: MyInlineElement | MyCodeLineElement | MyTableRowElement | MyTableCellElement | MyListItemElement | MyRootBlock) => boolean;
    isVoid: (element: MyInlineElement | MyCodeLineElement | MyTableRowElement | MyTableCellElement | MyListItemElement | MyRootBlock) => boolean;
    normalizeNode: (entry: TNodeEntry<ENode<MyValue>>) => void;
    apply: (operation: import("@udecode/plate-common").TOperation<EElementOrText<MyValue>>) => void;
    getFragment: () => EElementOrText<MyValue>[];
    insertFragment: (fragment: EElementOrText<MyValue>[]) => void;
    insertNode: (node: EElementOrText<MyValue> | EElementOrText<MyValue>[]) => void;
}>;
export declare const useMyEditorRef: () => MyEditor;
export declare const useMyEditorState: () => MyEditor;
export declare const useMyPlateEditorRef: (id?: PlateId) => MyEditor;
export declare const useMyPlateEditorState: (id?: PlateId) => MyEditor;
export declare const useMyPlateSelectors: (id?: PlateId) => import("@udecode/plate-common").GetRecord<import("@udecode/plate-common").PlateStoreState<MyValue, MyEditor>>;
export declare const useMyPlateActions: (id?: PlateId) => import("@udecode/plate-common").SetRecord<import("@udecode/plate-common").PlateStoreState<MyValue, MyEditor>>;
export declare const useMyPlateStates: (id?: PlateId) => import("@udecode/plate-common").UseRecord<import("@udecode/plate-common").PlateStoreState<MyValue, MyEditor>>;
/**
 * Utils
 */
export declare const createMyEditor: () => MyEditor;
export declare const createMyPlateEditor: (options?: CreatePlateEditorOptions<MyValue, MyEditor>) => any;
export declare const createMyPluginFactory: <P = import("@udecode/plate-common").AnyObject>(defaultPlugin: PlatePlugin<NoInfer<P>, MyValue, MyEditor>) => <OP = P, OV extends import("@udecode/plate-common").Value = MyValue, OE extends PlateEditor<OV> = PlateEditor<OV>>(override?: Partial<PlatePlugin<NoInfer<OP>, OV, OE>> | undefined, overrideByKey?: OverrideByKey<OV, OE> | undefined) => PlatePlugin<NoInfer<OP>, OV, OE>;
export declare const createMyPlugins: (plugins: MyPlatePlugin[], options?: {
    components?: Record<string, PlatePluginComponent>;
    overrideByKey?: MyOverrideByKey;
}) => PlatePlugin<any, MyValue, MyEditor>[];
export type MyAutoformatRule = AutoformatRule<MyValue, MyEditor>;
